@@ -36,6 +36,7 @@ from calibre.devices.interface import DevicePlugin as Device
 from calibre.ebooks.lrf.html.color_map import lrs_color
 from calibre.ebooks.chardet import xml_to_unicode
 
+
 def update_css(ncss, ocss):
     for key in ncss.keys():
         if ocss.has_key(key):  # noqa
@@ -43,6 +44,7 @@ def update_css(ncss, ocss):
         else:
             ocss[key] = ncss[key]
 
+
 def munge_paths(basepath, url):
     purl = urlparse(unquote(url),)
     path, fragment = purl[2], purl[5]
@@ -59,6 +61,7 @@ def munge_paths(basepath, url):
         path = os.path.join(dn, path)
     return os.path.normpath(path), fragment
 
+
 def strip_style_comments(match):
     src = match.group()
     while True:
@@ -72,11 +75,13 @@ def strip_style_comments(match):
         src = src[:lindex] + src[rindex+2:]
     return src
 
+
 def tag_regex(tagname):
     '''Return non-grouping regular expressions that match the opening and closing tags for tagname'''
     return dict(open=r'(?:<\s*%(t)s\s+[^<>]*?>|<\s*%(t)s\s*>)'%dict(t=tagname),
                 close=r'</\s*%(t)s\s*>'%dict(t=tagname))
 
+
 class HTMLConverter(object):
     SELECTOR_PAT   = re.compile(r"([A-Za-z0-9\-\_\:\.]+[A-Za-z0-9\-\_\:\.\s\,]*)\s*\{([^\}]*)\}")
     PAGE_BREAK_PAT = re.compile(r'page-break-(?:after|before)\s*:\s*(\w+)', re.IGNORECASE)
@@ -598,7 +603,7 @@ class HTMLConverter(object):
                hasattr(target.parent, 'objId'):
                 self.book.addTocEntry(ascii_text, tb)
             else:
-                self.log.debug(_("Cannot add link %s to TOC")%ascii_text)
+                self.log.debug("Cannot add link %s to TOC"%ascii_text)
 
         def get_target_block(fragment, targets):
             '''Return the correct block for the <a name> element'''
@@ -1802,6 +1807,7 @@ class HTMLConverter(object):
         for _file in self.scaled_images.values() + self.rotated_images.values():
             _file.__del__()
 
+
 def process_file(path, options, logger):
     if not isinstance(path, unicode):
         path = path.decode(sys.getfilesystemencoding())
@@ -1920,6 +1926,7 @@ def process_file(path, options, logger):
     conv.cleanup()
     return oname
 
+
 def try_opf(path, options, logger):
     if hasattr(options, 'opf'):
         opf = options.opf
@@ -1971,7 +1978,4 @@ def try_opf(path, options, logger):
         if not getattr(options, 'toc', None):
             options.toc   = opf.toc
     except Exception:
-        logger.exception(_('Failed to process opf file'))
-
-
-
+        logger.exception(_('Failed to process OPF file'))
