@@ -25,7 +25,7 @@ from calibre.ebooks.metadata import (
     title_sort, string_to_authors, check_isbn, authors_to_sort_string)
 from calibre.ebooks.metadata.meta import get_metadata
 from calibre.gui2 import (file_icon_provider, UNDEFINED_QDATETIME,
-        choose_files, error_dialog, choose_images)
+        choose_files, error_dialog, choose_images, gprefs)
 from calibre.gui2.complete2 import EditWithComplete
 from calibre.utils.date import (
     local_tz, qt_to_dt, as_local_time, UNDEFINED_DATE, is_date_undefined,
@@ -45,6 +45,7 @@ OK_COLOR = 'rgba(0, 255, 0, 12%)'
 ERR_COLOR = 'rgba(255, 0, 0, 12%)'
 INDICATOR_SHEET = 'QLineEdit { color: black; background-color: %s }'
 
+
 def save_dialog(parent, title, msg, det_msg=''):
     d = QMessageBox(parent)
     d.setWindowTitle(title)
@@ -52,9 +53,11 @@ def save_dialog(parent, title, msg, det_msg=''):
     d.setStandardButtons(QMessageBox.Yes | QMessageBox.No | QMessageBox.Cancel)
     return d.exec_()
 
+
 def clean_text(x):
     return re.sub(r'\s', ' ', x.strip())
 
+
 '''
 The interface common to all widgets used to set basic metadata
 class BasicMetadataWidget(object):
@@ -77,6 +80,7 @@ class BasicMetadataWidget(object):
         return property(fget=fget, fset=fset)
 '''
 
+
 class ToMetadataMixin(object):
 
     FIELD_NAME = None
@@ -108,6 +112,7 @@ class ToMetadataMixin(object):
         else:
             self.setEditText(text)
 
+
 def make_undoable(spinbox):
     'Add a proper undo/redo capability to spinbox which must be a sub-class of QAbstractSpinBox'
 
@@ -181,6 +186,8 @@ def make_undoable(spinbox):
     return UndoableSpinbox
 
 # Title {{{
+
+
 class TitleEdit(EnLineEdit, ToMetadataMixin):
 
     TITLE_ATTR = FIELD_NAME = 'title'
@@ -234,6 +241,7 @@ class TitleEdit(EnLineEdit, ToMetadataMixin):
     def break_cycles(self):
         self.dialog = None
 
+
 class TitleSortEdit(TitleEdit, ToMetadataMixin):
 
     TITLE_ATTR = FIELD_NAME = 'title_sort'
@@ -314,6 +322,8 @@ class TitleSortEdit(TitleEdit, ToMetadataMixin):
 # }}}
 
 # Authors {{{
+
+
 class AuthorsEdit(EditWithComplete, ToMetadataMixin):
 
     TOOLTIP = ''
@@ -422,6 +432,7 @@ class AuthorsEdit(EditWithComplete, ToMetadataMixin):
         except:
             pass
 
+
 class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
 
     TOOLTIP = _('Specify how the author(s) of this book should be sorted. '
@@ -571,6 +582,8 @@ class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
 # }}}
 
 # Series {{{
+
+
 class SeriesEdit(EditWithComplete, ToMetadataMixin):
 
     TOOLTIP = _('List of known series. You can add new series.')
@@ -707,6 +720,7 @@ class SeriesIndexEdit(make_undoable(QDoubleSpinBox), ToMetadataMixin):
 
 # }}}
 
+
 class BuddyLabel(QLabel):  # {{{
 
     def __init__(self, buddy):
@@ -717,6 +731,7 @@ class BuddyLabel(QLabel):  # {{{
 
 # Formats {{{
 
+
 class Format(QListWidgetItem):
 
     def __init__(self, parent, ext, size, path=None, timestamp=None):
@@ -733,6 +748,7 @@ class Format(QListWidgetItem):
             self.setToolTip(text)
             self.setStatusTip(text)
 
+
 class OrigAction(QAction):
 
     restore_fmt = pyqtSignal(object)
@@ -745,6 +761,7 @@ class OrigAction(QAction):
     def _triggered(self):
         self.restore_fmt.emit(self.fmt)
 
+
 class FormatList(_FormatList):
 
     restore_fmt = pyqtSignal(object)
@@ -773,6 +790,7 @@ class FormatList(_FormatList):
                 self.takeItem(i)
                 break
 
+
 class FormatsManager(QWidget):
 
     def __init__(self, parent, copy_fmt):
@@ -1008,6 +1026,7 @@ class FormatsManager(QWidget):
         self.temp_files = []
 # }}}
 
+
 class Cover(ImageView):  # {{{
 
     download_cover = pyqtSignal()
@@ -1032,7 +1051,7 @@ class Cover(ImageView):  # {{{
                     self.clicked.connect(action)
 
         self.select_cover_button = CB(_('&Browse'), 'document_open.png', self.select_cover)
-        self.trim_cover_button = b = CB(_('T&rim borders'), 'trim.png')
+        self.trim_cover_button = b = CB(_('Trim bord&ers'), 'trim.png')
         b.setToolTip(_(
             'Automatically detect and remove extra space at the cover\'s edges.\n'
             'Pressing it repeatedly can sometimes remove stubborn borders.'))
@@ -1164,6 +1183,7 @@ class Cover(ImageView):  # {{{
     def current_val(self):
         def fget(self):
             return self._cdata
+
         def fset(self, cdata):
             self._cdata = None
             self.cdata_before_trim = None
@@ -1206,6 +1226,7 @@ class Cover(ImageView):  # {{{
 
 # }}}
 
+
 class CommentsEdit(Editor, ToMetadataMixin):  # {{{
 
     FIELD_NAME = 'comments'
@@ -1215,6 +1236,7 @@ class CommentsEdit(Editor, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return self.html
+
         def fset(self, val):
             if not val or not val.strip():
                 val = ''
@@ -1234,6 +1256,7 @@ class CommentsEdit(Editor, ToMetadataMixin):  # {{{
             db.set_comment(id_, self.current_val, notify=False, commit=False)
 # }}}
 
+
 class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
     LABEL = _('&Rating:')
     TOOLTIP = _('Rating of this book. 0-5 stars')
@@ -1248,6 +1271,7 @@ class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return self.rating_value
+
         def fset(self, val):
             self.rating_value = val
         return property(fget=fget, fset=fset)
@@ -1266,6 +1290,7 @@ class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
 
 # }}}
 
+
 class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
     LABEL = _('Ta&gs:')
     TOOLTIP = '<p>'+_('Tags categorize the book. This is particularly '
@@ -1275,7 +1300,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
     def __init__(self, parent):
         EditWithComplete.__init__(self, parent)
-        self.lineEdit().setMaxLength(65536)  # see https://bugs.launchpad.net/bugs/1569388
+        self.lineEdit().setMaxLength(655360)  # see https://bugs.launchpad.net/bugs/1630944
         self.books_to_refresh = set([])
         self.setToolTip(self.TOOLTIP)
         self.setWhatsThis(self.TOOLTIP)
@@ -1284,6 +1309,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return [clean_text(x) for x in unicode(self.text()).split(',')]
+
         def fset(self, val):
             if not val:
                 val = []
@@ -1330,6 +1356,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
 # }}}
 
+
 class LanguagesEdit(LE, ToMetadataMixin):  # {{{
 
     LABEL = _('&Languages:')
@@ -1344,6 +1371,7 @@ class LanguagesEdit(LE, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return self.lang_codes
+
         def fset(self, val):
             self.set_lang_codes(val, self.allow_undo)
         return property(fget=fget, fset=fset)
@@ -1373,6 +1401,7 @@ class LanguagesEdit(LE, ToMetadataMixin):  # {{{
 
 # Identifiers {{{
 
+
 class Identifiers(Dialog):
 
     def __init__(self, identifiers, parent=None):
@@ -1418,8 +1447,9 @@ class Identifiers(Dialog):
             return
         Dialog.accept(self)
 
+
 class IdentifiersEdit(QLineEdit, ToMetadataMixin):
-    LABEL = _('I&ds:')
+    LABEL = _('&Ids:')
     BASE_TT = _('Edit the identifiers for this book. '
             'For example: \n\n%s')%(
             'isbn:1565927249, doi:10.1000/182, amazon:1565927249')
@@ -1460,9 +1490,11 @@ class IdentifiersEdit(QLineEdit, ToMetadataMixin):
                             c = v
                     ans[itype] = c
             return ans
+
         def fset(self, val):
             if not val:
                 val = {}
+
             def keygen(x):
                 x = x[0]
                 if x == 'isbn':
@@ -1497,13 +1529,30 @@ class IdentifiersEdit(QLineEdit, ToMetadataMixin):
             col = 'none'
         elif check_isbn(isbn) is not None:
             col = OK_COLOR
-            extra = '\n\n'+_('This ISBN number is valid')
+            extra = '\n\n'+_('This ISBN is valid')
         else:
             col = ERR_COLOR
-            extra = '\n\n' + _('This ISBN number is invalid')
+            extra = '\n\n' + _('This ISBN is invalid')
         self.setToolTip(tt+extra)
         self.setStyleSheet(INDICATOR_SHEET % col)
 
+    def paste_identifier(self):
+        try:
+            prefix = gprefs['paste_isbn_prefixes'][0]
+        except IndexError:
+            prefix = 'isbn'
+        self.paste_prefix(prefix)
+
+    def paste_prefix(self, prefix):
+        if prefix == 'isbn':
+            self.paste_isbn()
+        else:
+            text = unicode(QApplication.clipboard().text()).strip()
+            if text:
+                vals = self.current_val
+                vals[prefix] = text
+                self.current_val = vals
+
     def paste_isbn(self):
         text = unicode(QApplication.clipboard().text()).strip()
         if not text or not check_isbn(text):
@@ -1521,6 +1570,7 @@ class IdentifiersEdit(QLineEdit, ToMetadataMixin):
 
 # }}}
 
+
 class ISBNDialog(QDialog):  # {{{
 
     def __init__(self, parent, txt):
@@ -1561,10 +1611,10 @@ class ISBNDialog(QDialog):  # {{{
             extra = ''
         elif check_isbn(isbn) is not None:
             col = OK_COLOR
-            extra = _('This ISBN number is valid')
+            extra = _('This ISBN is valid')
         else:
             col = ERR_COLOR
-            extra = _('This ISBN number is invalid')
+            extra = _('This ISBN is invalid')
         self.line_edit.setToolTip(extra)
         self.line_edit.setStyleSheet(INDICATOR_SHEET % col)
 
@@ -1573,6 +1623,7 @@ class ISBNDialog(QDialog):  # {{{
 
 # }}}
 
+
 class PublisherEdit(EditWithComplete, ToMetadataMixin):  # {{{
     LABEL = _('&Publisher:')
     FIELD_NAME = 'publisher'
@@ -1624,12 +1675,14 @@ class PublisherEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
 # DateEdit {{{
 
+
 class CalendarWidget(QCalendarWidget):
 
     def showEvent(self, ev):
         if self.selectedDate().year() == UNDEFINED_DATE.year:
             self.setSelectedDate(QDate.currentDate())
 
+
 class DateEdit(make_undoable(QDateTimeEdit), ToMetadataMixin):
 
     TOOLTIP = ''
@@ -1665,6 +1718,7 @@ class DateEdit(make_undoable(QDateTimeEdit), ToMetadataMixin):
     def current_val(self):
         def fget(self):
             return qt_to_dt(self.dateTime(), as_utc=False)
+
         def fset(self, val):
             if val is None or is_date_undefined(val):
                 val = UNDEFINED_DATE
@@ -1695,11 +1749,16 @@ class DateEdit(make_undoable(QDateTimeEdit), ToMetadataMixin):
         elif ev.key() == Qt.Key_Equal:
             ev.accept()
             self.setDateTime(QDateTime.currentDateTime())
+        elif ev.key() == Qt.Key_Up and is_date_undefined(self.current_val):
+            self.setDateTime(QDateTime.currentDateTime())
+        elif ev.key() == Qt.Key_Tab and is_date_undefined(self.current_val):
+            ev.ignore()
         else:
             return super(DateEdit, self).keyPressEvent(ev)
 
+
 class PubdateEdit(DateEdit):
-    LABEL = _('Publishe&d:')
+    LABEL = _('P&ublished:')
     FMT = 'MMM yyyy'
     ATTR = FIELD_NAME = 'pubdate'
     TWEAK = 'gui_pubdate_display_format'
